@@ -1,9 +1,13 @@
 
+class Token:
+    ...
+
 
 class Tokenizer:
     def register(func):
         def wrapper(*args, **kwargs):
             pass
+
         return wrapper
 
     def batch_tokenize(self, texts):
