@@ -3,6 +3,9 @@ from typing import List
 
 
 class SentenceTokenizer:
+    """Simple Rule-based Sentence Splitter.
+    """
+
     PERIOD = "。"
     PERIOD_SPECIAL = "__PERIOD__"
 
@@ -11,14 +14,10 @@ class SentenceTokenizer:
         r"「.*?」",
     ]
 
-    def __init__(self) -> None:
-        pass
-
     @staticmethod
     def conv_period(item) -> str:
         return item.group(0).replace(
-            SentenceTokenizer.PERIOD,
-            SentenceTokenizer.PERIOD_SPECIAL
+            SentenceTokenizer.PERIOD, SentenceTokenizer.PERIOD_SPECIAL
         )
 
     def tokenize(self, document) -> List[str]:
